@@ -278,8 +278,8 @@ static void fill_combo_mode (XfburnBlankDialog *dialog)
 
 static gboolean is_valid_blank_mode (XfburnDevice *device, XfburnBlankMode mode)
 {
-  int profile_no;
-  gboolean erasable;
+  int profile_no = 0;
+  gboolean erasable = FALSE;
   enum burn_disc_status disc_state;
 
   XfburnDeviceList *devlist = xfburn_device_list_new ();
@@ -418,7 +418,7 @@ thread_blank_perform_blank (ThreadBlankParams * params, struct burn_drive_info *
     if(progress.sectors>0 && progress.sector>=0) {
       gdouble percent = 1.0 + ((gdouble) progress.sector+1.0) / ((gdouble) progress.sectors) * 98.0;
       
-      xfburn_progress_dialog_set_progress_bar_fraction (XFBURN_PROGRESS_DIALOG (dialog_progress), percent / 100.0);
+      xfburn_progress_dialog_set_progress_bar_fraction (XFBURN_PROGRESS_DIALOG (dialog_progress), percent);
     }
     usleep(500000);
   }
