@@ -54,6 +54,7 @@ typedef struct
   GtkWidget *entry;
   GtkWidget *check_eject;
   GtkWidget *check_burnfree;
+  GtkWidget *check_stream_recording;
   GtkWidget *check_only_iso;
   GtkWidget *hbox_iso;
   GtkWidget *entry_path_iso;
@@ -242,6 +243,11 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   gtk_widget_show (priv->check_burnfree);
   gtk_box_pack_start (GTK_BOX (vbox), priv->check_burnfree, FALSE, FALSE, BORDER);
 
+  priv->check_stream_recording = gtk_check_button_new_with_mnemonic (_("Stream _Recording"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->check_stream_recording), TRUE);
+  gtk_widget_show (priv->check_stream_recording);
+  gtk_box_pack_start (GTK_BOX (vbox), priv->check_stream_recording, FALSE, FALSE, BORDER);
+
   /* create ISO ? */
   priv->check_only_iso = gtk_check_button_new_with_mnemonic (_("Only create _ISO"));
   gtk_widget_show (priv->check_only_iso);
@@ -396,6 +402,7 @@ cb_check_only_iso_toggled (GtkToggleButton * button, XfburnBurnDataCompositionBa
   gtk_widget_set_sensitive (priv->hbox_iso, gtk_toggle_button_get_active (button));
   gtk_widget_set_sensitive (priv->check_eject, !gtk_toggle_button_get_active (button));
   gtk_widget_set_sensitive (priv->check_burnfree, !gtk_toggle_button_get_active (button));
+  gtk_widget_set_sensitive (priv->check_stream_recording, !gtk_toggle_button_get_active (button));
   gtk_widget_set_sensitive (priv->check_dummy, !gtk_toggle_button_get_active (button));
   if (!gtk_toggle_button_get_active (button)) {
     g_object_get (G_OBJECT (priv->device_box), "valid", &valid_disc, NULL);
@@ -503,7 +510,7 @@ thread_write_iso (ThreadWriteIsoParams * params)
 	gdouble percent = 0;
 	i = 0;
 
-	percent = ((gdouble) written / (gdouble) size);
+	percent = ((gdouble) written / (gdouble) size) * 100.0;
 
 	xfburn_progress_dialog_set_progress_bar_fraction (XFBURN_PROGRESS_DIALOG (dialog_progress), percent);
       }
@@ -529,6 +536,7 @@ typedef struct {
   gboolean eject;
   gboolean dummy;
   gboolean burnfree;
+  gboolean stream_recording;
 } ThreadBurnCompositionParams;
 
 static void 
@@ -566,6 +574,12 @@ thread_burn_prep_and_burn (ThreadBurnCompositionParams * params, struct burn_dri
   */
   burn_write_opts_set_simulate(burn_options, params->dummy ? 1 : 0);
   burn_write_opts_set_underrun_proof (burn_options, params->burnfree ? 1 : 0);
+  /*
+   * 32 is the number of blocks to skip. This will increase reliability with BD disks that
+   * are used for multisessions. xfburn doesn't support this, but other programs may be using
+   * the disc that way, so we respect that here.
+   */
+  burn_write_opts_set_stream_recording (burn_options, params->stream_recording ? 32 : 0);
 
   if (!xfburn_set_write_mode (burn_options, params->write_mode, disc, WRITE_MODE_TAO)) {
     xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The write mode is not supported currently."));
@@ -640,7 +654,7 @@ cb_dialog_response (XfburnBurnDataCompositionBaseDialog * dialog, gint response_
     /* Sets profile 0 [basic] */
     iso_write_opts_new (&write_opts, 0);
 
-    iso_write_opts_set_iso_level (write_opts, 2);
+    iso_write_opts_set_iso_level (write_opts, 3);
     iso_write_opts_set_rockridge (write_opts, 1);
     iso_write_opts_set_joliet (write_opts, 1);
     iso_write_opts_set_allow_deep_paths (write_opts, 1);
@@ -698,6 +712,7 @@ cb_dialog_response (XfburnBurnDataCompositionBaseDialog * dialog, gint response_
       params->eject = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_eject));
       params->dummy = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_dummy));
       params->burnfree = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_burnfree));
+      params->stream_recording = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_stream_recording));
       g_thread_new ("burn_composition", (GThreadFunc) thread_burn_composition, params);
     }
   }
