@@ -1,4 +1,3 @@
-/* $Id: xfburn-error.h 6210 2008-11-26 23:27:19Z squisher $ */
 /*
  * Copyright (c) 2008 David Mohr <david@mcbf.net>
  *
@@ -47,6 +46,6 @@ typedef enum
 
 #define XFBURN_ERROR xfburn_error_quark ()
 
-GQuark xfburn_error_quark ();
+GQuark xfburn_error_quark (void);
 
 #endif /* __XFBURN_ERROR_H__ */
