@@ -1,4 +1,3 @@
-/* $Id: xfburn-main.c 7695 2009-07-08 14:23:15Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -30,16 +29,13 @@
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
-
-#ifdef HAVE_THUNAR_VFS
-#include <thunar-vfs/thunar-vfs.h>
-#endif
+#include <libxfce4ui/libxfce4ui.h>
 
 #ifdef HAVE_GST
 #include <gst/gst.h>
 #endif
 
+#include "xfburn-main.h"
 #include "xfburn-global.h"
 #include "xfburn-device-list.h"
 #include "xfburn-utils.h"
@@ -48,7 +44,7 @@
 #include "xfburn-burn-image-dialog.h"
 #include "xfburn-main-window.h"
 #include "xfburn-blank-dialog.h"
-#include "xfburn-hal-manager.h"
+#include "xfburn-udev-manager.h"
 #include "xfburn-transcoder-basic.h"
 #include "xfburn-transcoder-gst.h"
 
@@ -56,6 +52,8 @@
 /* internal prototypes */
 static gboolean parse_option (const gchar *option_name, const gchar *value,
 			      gpointer data, GError **error);
+static void xfburn_main_enter_main_window (void);
+static void print_available_transcoders (void);
 
 /* globals */
 static int window_counter = 0;
@@ -90,9 +88,9 @@ static GOptionEntry optionentries[] = {
   { "directory", 'D', G_OPTION_FLAG_OPTIONAL_ARG , G_OPTION_ARG_CALLBACK, &parse_option, 
     "Start the file browser in the specified directory, or the current directory if none is specified (the default is to start in your home directory)", NULL },
 #endif
-  { "version", 'V', G_OPTION_FLAG_NO_ARG , G_OPTION_ARG_NONE, &show_version, 
+  { "version", 'V', 0 , G_OPTION_ARG_NONE, &show_version, 
     "Display program version and exit", NULL },
-  { "main", 'm', G_OPTION_FLAG_NO_ARG , G_OPTION_ARG_NONE, &show_main, 
+  { "main", 'm', 0, G_OPTION_ARG_NONE, &show_main, 
     "Show main program even when other action is specified on the command line.", NULL },
   { NULL, ' ', 0, 0, NULL, NULL, NULL }
 };
@@ -100,7 +98,7 @@ static GOptionEntry optionentries[] = {
 
 /* public functions */
 void
-xfburn_main_enter_window ()
+xfburn_main_enter_window (void)
 {
   /* if a main window is present, then it is in control */
   if (window_counter != -42)
@@ -108,7 +106,7 @@ xfburn_main_enter_window ()
 }
 
 void 
-xfburn_main_leave_window ()
+xfburn_main_leave_window (void)
 {
   /* if a main window is present, then it is in control */
   if (window_counter == -42)
@@ -119,8 +117,8 @@ xfburn_main_leave_window ()
     g_idle_add ((GSourceFunc) gtk_main_quit, NULL );
 }
 
-void
-xfburn_main_enter_main_window ()
+static void
+xfburn_main_enter_main_window (void)
 {
   /* mark the window_counter as having a main window */
   window_counter = -42;
@@ -170,8 +168,8 @@ static gboolean parse_option (const gchar *option_name, const gchar *value,
 }
 
 
-void
-print_available_transcoders ()
+static void
+print_available_transcoders (void)
 {
   g_print ("Valid transcoders are:\n");
   g_print ("\tbasic\tCan only burn uncompressed CD quality .wav files.\n");
@@ -187,7 +185,7 @@ main (int argc, char **argv)
   GtkWidget *mainwin;
   gint n_burners;
   GError *error = NULL;
-#ifdef HAVE_HAL
+#ifdef HAVE_GUDEV
   gchar *error_msg;
 #endif
   XfburnTranscoder *transcoder;
@@ -203,7 +201,6 @@ main (int argc, char **argv)
   
   g_set_application_name (_("Xfburn"));
 
-  g_thread_init (NULL);
   gdk_threads_init ();
   gdk_threads_enter ();
 
@@ -219,7 +216,7 @@ main (int argc, char **argv)
 
   if (!burn_initialize ()) {
     g_critical ("Unable to initialize libburn");
-    xfce_err (_("Unable to initialize the burning backend."));
+    xfce_dialog_show_error (NULL, NULL, _("Unable to initialize the burning backend."));
     gdk_threads_leave ();
     return EXIT_FAILURE;
   }
@@ -273,25 +270,15 @@ main (int argc, char **argv)
 
   xfburn_settings_init ();
   
-#ifdef HAVE_THUNAR_VFS
-  thunar_vfs_init ();
-  g_message ("Using Thunar-VFS %d.%d.%d", THUNAR_VFS_MAJOR_VERSION, THUNAR_VFS_MINOR_VERSION, THUNAR_VFS_MICRO_VERSION);
-#else
-  g_message ("Thunar-VFS not available, using default implementation");
-#endif
-  
-#ifdef HAVE_HAL
-  error_msg = xfburn_hal_manager_create_global ();
+#ifdef HAVE_GUDEV
+  error_msg = xfburn_udev_manager_create_global ();
   if (error_msg) {
-    xfce_err (error_msg);
-#ifdef HAVE_THUNAR_VFS
-    thunar_vfs_shutdown ();
-#endif
+    xfce_dialog_show_error (NULL, NULL, "%s", error_msg);
     gdk_threads_leave ();
     burn_finish ();
     return EXIT_FAILURE;
   } else {
-    g_message ("Using HAL");
+    g_message ("Using UDEV");
   }
 #endif
 
@@ -340,7 +327,7 @@ main (int argc, char **argv)
   }
 
   if (!xfburn_transcoder_is_initialized (transcoder, &error)) {
-    xfce_warn (_("Failed to initialize %s transcoder: %s\n\t(falling back to basic implementation)"), xfburn_transcoder_get_name (transcoder), error->message);
+    xfce_dialog_show_warning(NULL, NULL, _("Failed to initialize %s transcoder: %s\n\t(falling back to basic implementation)"), xfburn_transcoder_get_name (transcoder), error->message);
     g_error_free (error);
     g_object_unref (transcoder);
     transcoder = XFBURN_TRANSCODER (xfburn_transcoder_basic_new ());
@@ -352,6 +339,17 @@ main (int argc, char **argv)
 
   /*----------evaluate parsed command line action options-------------------------*/
 
+  /* heuristic for file names on the commandline */
+  if (argc == 2 && !add_data_composition) {
+    /* exactly one filename, assume it is an image */
+      image_filename = argv[1];
+  } else if (argc > 2) {
+    /* several file names, for now just open up a data composition */
+    /* TODO: auto-detect music files for audio compositions */
+    add_data_composition = TRUE;
+  }
+
+
   if (show_main) {
     xfburn_main_enter_main_window ();
   }
@@ -373,7 +371,7 @@ main (int argc, char **argv)
       if (g_file_test (image_fullname, G_FILE_TEST_EXISTS))
 	xfburn_burn_image_dialog_set_filechooser_name (dialog, image_fullname);
       else
-	xfce_err ( g_strdup_printf ( _("Image file '%s' does not exist."), image_fullname));
+        xfce_dialog_show_error (NULL, NULL, _("Image file '%s' does not exist."), image_fullname);
     }
 
     gtk_dialog_run (GTK_DIALOG (dialog));
@@ -411,14 +409,10 @@ main (int argc, char **argv)
   g_object_unref (devlist);
   g_object_unref (transcoder);
 
-#ifdef HAVE_HAL
-  xfburn_hal_manager_shutdown ();
+#ifdef HAVE_GUDEV
+  xfburn_udev_manager_shutdown ();
 #endif
 
-#ifdef HAVE_THUNAR_VFS
-  thunar_vfs_shutdown ();
-#endif
-  
   xfburn_settings_flush ();
   xfburn_settings_free ();
   
